import { WriteStream } from 'node:tty';

type BarSize = 'SMALL' | 'MEDIUM' | 'DEFAULT';
type Options = {
    /** The wriatable stream to use, default is stderr. */
    stream: WriteStream;
    /** The width of the rendered progress bar. */
    width: number;
    /** The foreground color of completed bars. */
    color: string;
    /** The background color of bars. */
    bgColor: string;
    /** Set true to remove the progress bar after it completed. */
    autoClear: boolean;
    /** The size of the progress bar to render, default is 30. */
    size: BarSize;
    /** The string to be prefixed progress bar */
    prefix: string;
    /** The string to be suffixed progress bar */
    suffix: string;
    /** Show hide progress bar percent */
    showPercent: boolean;
    /** Show hide progress bar count */
    showCount: boolean;
};
type Bar = Omit<Options, 'stream' | 'width' | 'autoClear'> & {
    id?: number;
    total: number;
    value: number;
    progress?: boolean;
};

declare class ProgressBar {
    private _options;
    private _bars;
    constructor(options?: Partial<Options>);
    private _getBarCharBySize;
    private _getBars;
    private _render;
    /** Starts rendering of the progress bars. */
    start(obj?: Partial<Bar>): void;
    private _clear;
    /** Stops the current progress bar with optional message to display. */
    stop(msg?: string): void;
    /** Update the current progress bar */
    update(obj: Partial<Bar>, id?: number): void;
    /** Adds a new progress bar to the rendering stack. */
    add(obj: Partial<Bar>): {
        update: (obj: Partial<Bar>) => void;
    } | null;
    /** Increment the value + 1, optionally with the provided value. */
    inc(bar?: Partial<Bar>, val?: number): void;
}

export { ProgressBar };
